"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = start;

var _toConsumableArray2 = _interopRequireDefault(require("@babel/runtime/helpers/toConsumableArray"));

require("./util/globals");

var _fs = _interopRequireDefault(require("fs"));

var _spdy = _interopRequireDefault(require("spdy"));

var _mwpConfig = _interopRequireDefault(require("mwp-config"));

var _routes = _interopRequireDefault(require("./routes"));

var _getPlugins = _interopRequireDefault(require("./util/getPlugins"));

var _util = require("./util");

// eventually this will be a native node module
var appConfig = _mwpConfig.default.getServer().properties;
/**
 * @module server
 */

/**
 * The start function applies the rendering function to the correct application
 * route and combines the provided routes and plugins with the base routes
 * and plugins
 *
 * @param {Object} languageRenderers A mapping of localeCodes to functions that emit
 *   the rendered HTML for the locale-specific request
 * @param {Array} routes additional routes for the app - cannot include a
 *   wildcard route
 * @param {Array} plugins additional plugins for the server, usually to support
 *   features in the additional routes
 * @return {Promise} the Promise returned by Hapi server
 */


function start(languageRenderers, _ref) {
  var _ref$routes = _ref.routes,
      routes = _ref$routes === void 0 ? [] : _ref$routes,
      _ref$plugins = _ref.plugins,
      plugins = _ref$plugins === void 0 ? [] : _ref$plugins;

  // source maps make for better stack traces
  // we might not want this in production if it makes anything slower
  require('source-map-support').install();

  (0, _util.configureEnv)(appConfig);
  var baseRoutes = (0, _routes.default)();
  var finalRoutes = [].concat((0, _toConsumableArray2.default)(routes), (0, _toConsumableArray2.default)(baseRoutes));
  var serverConfig = {
    host: '0.0.0.0',
    port: appConfig.app_server.port,
    // accessed via server.settings.app
    app: appConfig,
    // accessed via server.settings.plugins
    plugins: {
      'electrode-csrf-jwt': {
        enabled: false
      },
      'mwp-logger-plugin': {
        enabled: true
      }
    }
  };

  if (appConfig.app_server.protocol === 'https') {
    // enable https
    serverConfig.tls = true; // enable HTTP/2

    serverConfig.listener = _spdy.default.createServer({
      key: _fs.default.readFileSync(appConfig.app_server.key_file),
      cert: _fs.default.readFileSync(appConfig.app_server.crt_file)
    });
  }

  var finalPlugins = [].concat((0, _toConsumableArray2.default)(plugins), (0, _toConsumableArray2.default)((0, _getPlugins.default)({
    languageRenderers: languageRenderers
  })));
  appConfig.supportedLangs = Object.keys(languageRenderers);
  return (0, _util.server)(serverConfig, finalRoutes, finalPlugins, appConfig);
}
//# sourceMappingURL=index.js.map