"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.checkForDevUrl = checkForDevUrl;
exports.onRequestExtension = onRequestExtension;
exports.onPreResponseExtension = onPreResponseExtension;
exports.registerExtensionEvents = registerExtensionEvents;
exports.configureEnv = configureEnv;
exports.server = server;

var _regenerator = _interopRequireDefault(require("@babel/runtime/regenerator"));

var _asyncToGenerator2 = _interopRequireDefault(require("@babel/runtime/helpers/asyncToGenerator"));

var _typeof2 = _interopRequireDefault(require("@babel/runtime/helpers/typeof"));

var _https = _interopRequireDefault(require("https"));

var _hapi = _interopRequireDefault(require("hapi"));

var _uuid = _interopRequireDefault(require("uuid"));

/**
 * determine whether a nested object of values has
 * a string that contains `.dev.meetup.`
 *
 * @param {String|Object} value string or nested object
 * with values that could be URL strings
 *
 * @return {Boolean} whether the `value` contains a 'dev' URL string
 */
function checkForDevUrl(value) {
  switch ((0, _typeof2.default)(value)) {
    case 'string':
      return value.indexOf('.dev.meetup.') > -1;

    case 'object':
      return Object.keys(value).some(function (key) {
        return checkForDevUrl(value[key]);
      });
  }

  return false;
}

function onRequestExtension(request, h) {
  request.id = _uuid.default.v4(); // provide uuid for request instead of default Hapi id

  return h.continue;
}

function onPreResponseExtension(request, h) {
  // happens with OPTIONS request
  if (typeof request.response.header !== 'function') {
    return h.continue;
  } // set a response header with the value of the version tag env variable


  request.response.header('x-version-tag', process.env.VERSION_TAG);
  return h.continue;
}
/**
 * Use server.ext to add functions to request/server extension points
 * @see {@link https://hapijs.com/api#request-lifecycle}
 * @param {Object} server Hapi server
 * @return {Object} Hapi server
 */


function registerExtensionEvents(server) {
  server.ext({
    type: 'onRequest',
    method: onRequestExtension
  });

  if (process.env.VERSION_TAG) {
    server.ext({
      type: 'onPreResponse',
      method: onPreResponseExtension
    });
  }

  return server;
}
/**
 * Make any environment changes that need to be made in response to the provided
 * config
 *
 * @param {Object} config the environment configuration object
 *
 * @return null
 */


function configureEnv(config) {
  // When using .dev.meetup endpoints, ignore self-signed SSL cert
  var USING_DEV_ENDPOINTS = checkForDevUrl(config);
  _https.default.globalAgent.options.rejectUnauthorized = !USING_DEV_ENDPOINTS;
}
/**
 * server-starting function
 */


function server(_x, _x2, _x3) {
  return _server.apply(this, arguments);
}

function _server() {
  _server = (0, _asyncToGenerator2.default)(
  /*#__PURE__*/
  _regenerator.default.mark(function _callee(serverConfig, routes, plugins) {
    var server;
    return _regenerator.default.wrap(function _callee$(_context) {
      while (1) {
        switch (_context.prev = _context.next) {
          case 0:
            server = _hapi.default.server(serverConfig); // register plugins

            _context.next = 3;
            return server.register(plugins);

          case 3:
            _context.next = 5;
            return registerExtensionEvents(server);

          case 5:
            _context.next = 7;
            return server.auth.strategy('default', 'mwp');

          case 7:
            _context.next = 9;
            return server.auth.default('default');

          case 9:
            _context.next = 11;
            return server.route(routes);

          case 11:
            _context.prev = 11;
            _context.next = 14;
            return server.start();

          case 14:
            _context.next = 19;
            break;

          case 16:
            _context.prev = 16;
            _context.t0 = _context["catch"](11);
            // TODO: add logging
            console.log(_context.t0);

          case 19:
            return _context.abrupt("return", server);

          case 20:
          case "end":
            return _context.stop();
        }
      }
    }, _callee, null, [[11, 16]]);
  }));
  return _server.apply(this, arguments);
}
//# sourceMappingURL=index.js.map