"use strict";

var _interopRequireWildcard = require("@babel/runtime/helpers/interopRequireWildcard");

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");

var _regenerator = _interopRequireDefault(require("@babel/runtime/regenerator"));

var _asyncToGenerator2 = _interopRequireDefault(require("@babel/runtime/helpers/asyncToGenerator"));

var _convict = _interopRequireDefault(require("convict"));

var _https = _interopRequireDefault(require("https"));

var _mwpTestUtils = require("mwp-test-utils");

var serverUtils = _interopRequireWildcard(require("./"));

describe('checkForDevUrl', function () {
  it('returns true for dev URLs', function () {
    expect(serverUtils.checkForDevUrl('www.dev.meetup.com')).toBe(true);
    expect(serverUtils.checkForDevUrl('secure.dev.meetup.com')).toBe(true);
  });
  it('rejects non-dev URLs and non-objects', function () {
    expect(serverUtils.checkForDevUrl('www.meetup.com')).toBe(false);
    expect(serverUtils.checkForDevUrl('secure.meetup.com')).toBe(false);
    expect(serverUtils.checkForDevUrl(1234)).toBe(false);
    expect(serverUtils.checkForDevUrl(true)).toBe(false);
    expect(serverUtils.checkForDevUrl(new Date())).toBe(false);
  });
  it('returns true for nested dev URLs', function () {
    expect(serverUtils.checkForDevUrl({
      url: 'www.dev.meetup.com'
    })).toBe(true);
    expect(serverUtils.checkForDevUrl({
      url1: 'www.meetup.com',
      url2: 'www.dev.meetup.com'
    })).toBe(true);
    expect(serverUtils.checkForDevUrl({
      url: {
        url: 'www.dev.meetup.com'
      }
    })).toBe(true);
  });
});
describe('configureEnv', function () {
  var _this = this;

  beforeEach(function () {
    // cache the 'default' setting for rejectUnauthorized
    _this.defaultRejectUnauthorized = _https.default.globalAgent.options.rejectUnauthorized;
  });
  afterEach(function () {
    // restore the default setting for rejectUnauthorized
    _https.default.globalAgent.options.rejectUnauthorized = this.defaultRejectUnauthorized;
  });
  it('sets global rejectUnauthorized to false when using dev URLs in config', function () {
    serverUtils.configureEnv((0, _convict.default)({
      url: 'www.dev.meetup.com'
    }));
    expect(_https.default.globalAgent.options.rejectUnauthorized).toBe(false);
  });
  it('sets global rejectUnauthorized to true when using prod URLs in config', function () {
    serverUtils.configureEnv((0, _convict.default)({
      url: 'www.meetup.com'
    }));
    expect(_https.default.globalAgent.options.rejectUnauthorized).toBe(true);
  });
});
describe('onRequestExtension',
/*#__PURE__*/
(0, _asyncToGenerator2.default)(
/*#__PURE__*/
_regenerator.default.mark(function _callee() {
  var server, request;
  return _regenerator.default.wrap(function _callee$(_context) {
    while (1) {
      switch (_context.prev = _context.next) {
        case 0:
          _context.next = 2;
          return (0, _mwpTestUtils.getServer)();

        case 2:
          server = _context.sent;
          request = {
            headers: 'foo',
            id: 'bar',
            method: 'get',
            info: {},
            url: {
              href: 'http://example.com'
            },
            state: {},
            server: server
          };
          it('returns h.continue', function () {
            var h = {
              continue: {}
            };
            var response = serverUtils.onRequestExtension(request, h);
            expect(response).toEqual(h.continue);
          });

        case 5:
        case "end":
          return _context.stop();
      }
    }
  }, _callee);
})));
//# sourceMappingURL=index.test.js.map